@@ -139,7 +139,7 @@ stringFunc <- function (x)  {
       } else constString <- NULL
       theDots <- list(...)
       theDots$x <- tuneAcc
-      if(!(any(names(theDots) == "digits"))) theDots$digits <- min(3, getOption("digits") - 3)
+#       if(!(any(names(theDots) == "digits"))) theDots$digits <- min(3, getOption("digits"))
       printMat <- do.call("format.data.frame", theDots)
       printMat <- as.matrix(printMat)
       rownames(printMat) <- rep("", dim(printMat)[1])
